==> activity-custom-center-api-0.2.53-sources.jar: cn/com/duiba/activity/custom/center/api/dto/ccb/JhActivityWhiteHistoryDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.ccb;

import java.io.Serializable;
import java.util.Date;

/**
 * @author JunAngLiu
 * @Title: JhActivityWhiteHistoryDto
 * @Description: 建行录入活动历史
 * @date 2019/10/2417:22
 */
public class JhActivityWhiteHistoryDto implements Serializable {

    private static final long serialVersionUID = -4643215256294087358L;

    private Long id;
    //客户经理编码
    private String managerCode;
    //活动编码
    private String activityCode;
    //客户手机号
    private String customerPhone;
    //创建时间
    private Date gmtCreate;
    //修改时间
    private Date gmtModified;

    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getManagerCode() {
        return managerCode;
    }

    public void setManagerCode(String managerCode) {
        this.managerCode = managerCode;
    }

    public String getActivityCode() {
        return activityCode;
    }

    public void setActivityCode(String activityCode) {
        this.activityCode = activityCode;
    }

    public String getCustomerPhone() {
        return customerPhone;
    }

    public void setCustomerPhone(String customerPhone) {
        this.customerPhone = customerPhone;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }
}

==> activity-custom-center-api-0.3.16-sources.jar: cn/com/duiba/activity/custom/center/api/dto/ccb/JhActivityWhiteHistoryDto.java <==
package cn.com.duiba.activity.custom.center.api.dto.ccb;

import cn.com.duiba.activity.custom.center.api.enums.ccb.WhiteListRecordStatusEnum;

import java.io.Serializable;
import java.util.Date;

/**
 * @author JunAngLiu
 * @Title: JhActivityWhiteHistoryDto
 * @Description: 建行录入活动历史
 * @date 2019/10/2417:22
 */
public class JhActivityWhiteHistoryDto implements Serializable {

    private static final long serialVersionUID = -4643215256294087358L;

    private Long id;
    //客户经理编码
    private String managerCode;
    //活动编码
    private String activityCode;
    //客户手机号
    private String customerPhone;
    //创建时间
    private Date gmtCreate;
    //修改时间
    private Date gmtModified;

    /**
     * 记录状态 0-待处理 1-录入成功 2-录入失败 3-录入超时
     * {@link WhiteListRecordStatusEnum}
     */
    private Integer recordStatus;

    /**
     * 录入日期
     * yyyyMMdd
     * 0-正常录入
     * 非0-超时录入
     */
    private Integer recordDate;


    public Long getId() {
        return id;
    }

    public void setId(Long id) {
        this.id = id;
    }

    public String getManagerCode() {
        return managerCode;
    }

    public void setManagerCode(String managerCode) {
        this.managerCode = managerCode;
    }

    public String getActivityCode() {
        return activityCode;
    }

    public void setActivityCode(String activityCode) {
        this.activityCode = activityCode;
    }

    public String getCustomerPhone() {
        return customerPhone;
    }

    public void setCustomerPhone(String customerPhone) {
        this.customerPhone = customerPhone;
    }

    public Date getGmtCreate() {
        return gmtCreate;
    }

    public void setGmtCreate(Date gmtCreate) {
        this.gmtCreate = gmtCreate;
    }

    public Date getGmtModified() {
        return gmtModified;
    }

    public void setGmtModified(Date gmtModified) {
        this.gmtModified = gmtModified;
    }

    public Integer getRecordStatus() {
        return recordStatus;
    }

    public void setRecordStatus(Integer recordStatus) {
        this.recordStatus = recordStatus;
    }

    public Integer getRecordDate() {
        return recordDate;
    }

    public void setRecordDate(Integer recordDate) {
        this.recordDate = recordDate;
    }
}
